@@ -228,6 +228,9 @@ cd_profile_set_metadata (CdProfile *profile,
 			 const gchar *property,
 			 const gchar *value)
 {
+	/* i1Profiler sets this */
+	if (g_strcmp0 (property, "CreatorApp") == 0)
+		property = CD_PROFILE_METADATA_CMF_PRODUCT;
 	g_hash_table_insert (profile->priv->metadata,
 			     g_strdup (property),
 			     g_strdup (value));
@@ -931,6 +934,7 @@ cd_profile_set_from_profile (CdProfile *profile,
 	lcms_profile = cd_icc_get_handle (icc);
 	ret = cmsGetHeaderCreationDateTime (lcms_profile, &created);
 	if (ret) {
+		created.tm_isdst = -1;
 		priv->created = mktime (&created);
 	} else {
 		g_warning ("failed to get created time");
@@ -1194,7 +1198,6 @@ cd_profile_set_fd (CdProfile *profile,
 	}
 
 	/* create a mapped file */
-#if GLIB_CHECK_VERSION(2,31,0)
 	priv->mapped_file = g_mapped_file_new_from_fd (fd, FALSE, error);
 	if (priv->mapped_file == NULL) {
 		g_set_error (error,
@@ -1204,7 +1207,6 @@ cd_profile_set_fd (CdProfile *profile,
 			     fd);
 		goto out;
 	}
-#endif
 
 	/* set the virtual profile from the lcms profile */
 	ret = cd_profile_set_from_profile (profile, icc, error);
